CloudService #
A CloudService is data of an instance of a resource. A CloudService follows the pre-created classification system of a CloudServiceType and indicates the property value of the resource.
Package : spaceone.api.inventory.v1
CloudService #
CloudService Methods:
create #
Creates a new CloudService. A CloudService instance is created based on data including the resource’s attribute values. When creating, the classification information defined by CloudServiceType is also needed. The created CloudService has collection information which is the collection history for the resource by plugin.
POST /inventory/v1/cloud-service/create
cloud_service_type (string)
Requiredprovider (string)
Requiredcloud_service_group (string)
Requireddata (Struct)
Requireddomain_id (string)
Requiredname (string)
account (string)
instance_type (string)
instance_size (float)
ip_addresses (string)
Repeatedmetadata (Struct)
reference (CloudServiceReference)
tags (Struct)
region_code (string)
project_id (string)
{
"cloud_service_type": "Key",
"provider": "aws",
"cloud_service_group": "KMS",
"name": "cloud_service_test",
"account": "251340636361",
"launched_at": "2020-08-03T15:00:54.000Z",
"ip_addresses": [],
"data": {
"alias_arn": null,
"origin": "AWS_KMS",
"cloudwatch": {
"region_name": "ap-northeast-1",
"namespace": "AWS/KMS",
"dimensions": [
{
"Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"Name": "KeyId"
}
]
},
"aws_account_id": "251340636361",
"creation_date": "2020-07-09T09:39:03.097000+0000",
"encryption_algorithms": [
"SYMMETRIC_DEFAULT"
],
"key_usage": "ENCRYPT_DECRYPT",
"key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_type_path": "defaultKeys",
"key_rotated": false,
"description": "Default master key that protects my Secrets Manager data when no other key is defined",
"key_state": "Enabled",
"customer_master_key_spec": "SYMMETRIC_DEFAULT",
"enabled": true,
"arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_manager": "AWS"
},
"metadata": {},
"reference": {
"resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
},
"tags": {
"a": "b"
},
"region_code": "ap-northeast-1"
}cloud_service_id (string)
Requiredname (string)
Requiredstate (string)
Requiredaccount (string)
Requiredinstance_type (string)
Requiredinstance_size (float)
Requiredcloud_service_type (string)
Requiredcloud_service_group (string)
Requiredprovider (string)
Requireddata (Struct)
Requiredmetadata (Struct)
Requiredreference (CloudServiceReference)
Requiredtags (Struct)
Requiredtag_keys (Struct)
Requiredcollection_info (CollectionInfo)
RepeatedRequiredip_addresses (string)
RepeatedRequiredregion_code (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Requireddeleted_at (string)
Required
{
"cloud_service_id": "cloud-svc-c00f38a173e1",
"name": "cloud_service_test",
"state": "ACTIVE",
"account": "251340636361",
"cloud_service_type": "Key",
"cloud_service_group": "KMS",
"provider": "aws",
"data": {
"alias_arn": null,
"origin": "AWS_KMS",
"cloudwatch": {
"region_name": "ap-northeast-1",
"namespace": "AWS/KMS",
"dimensions": [
{
"Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"Name": "KeyId"
}
]
},
"aws_account_id": "251340636361",
"creation_date": "2020-07-09T09:39:03.097000+0000",
"encryption_algorithms": [
"SYMMETRIC_DEFAULT"
],
"key_usage": "ENCRYPT_DECRYPT",
"key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_type_path": "defaultKeys",
"key_rotated": false,
"description": "Default master key that protects my Secrets Manager data when no other key is defined",
"key_state": "Enabled",
"customer_master_key_spec": "SYMMETRIC_DEFAULT",
"enabled": true,
"arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_manager": "AWS"
},
"metadata": {
"manual": {}
},
"reference": {
"resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
},
"tags": {
"a": "b"
},
"collection_info": {
"collectors": [],
"service_accounts": [],
"secrets": []
},
"ip_addresses": [],
"region_code": "ap-northeast-1",
"domain_id": "domain-58010aa2e451",
"created_at": "2022-06-22T06:38:48.989Z",
"updated_at": "2022-06-22T06:38:48.989Z",
"launched_at": "2020-08-03T15:00:54.000Z"
}update #
Updates a specific CloudService. You can make changes in CloudService settings, except for the classification system of CloudService and the information about the resource attribute value.
POST /inventory/v1/cloud-service/update
cloud_service_id (string)
Requireddomain_id (string)
Requiredname (string)
account (string)
instance_type (string)
instance_size (float)
ip_addresses (string)
Repeateddata (Struct)
metadata (Struct)
reference (CloudServiceReference)
tags (Struct)
region_code (string)
project_id (string)
release_project (bool)
release_region (bool)
{
"cloud_service_id": "cloud-svc-c00f38a173e1",
"name": "cloud_service_test2",
"ip_addresses": [
"1.1.1.1",
"2.2.2.2"
],
"tags": {
"description": "spaceone"
},
"region_code": "ap-northeast-2"
}cloud_service_id (string)
Requiredname (string)
Requiredstate (string)
Requiredaccount (string)
Requiredinstance_type (string)
Requiredinstance_size (float)
Requiredcloud_service_type (string)
Requiredcloud_service_group (string)
Requiredprovider (string)
Requireddata (Struct)
Requiredmetadata (Struct)
Requiredreference (CloudServiceReference)
Requiredtags (Struct)
Requiredtag_keys (Struct)
Requiredcollection_info (CollectionInfo)
RepeatedRequiredip_addresses (string)
RepeatedRequiredregion_code (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Requireddeleted_at (string)
Required
{
"cloud_service_id": "cloud-svc-c00f38a173e1",
"name": "cloud_service_test",
"state": "ACTIVE",
"account": "251340636361",
"cloud_service_type": "Key",
"cloud_service_group": "KMS",
"provider": "aws",
"data": {
"alias_arn": null,
"origin": "AWS_KMS",
"cloudwatch": {
"region_name": "ap-northeast-1",
"namespace": "AWS/KMS",
"dimensions": [
{
"Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"Name": "KeyId"
}
]
},
"aws_account_id": "251340636361",
"creation_date": "2020-07-09T09:39:03.097000+0000",
"encryption_algorithms": [
"SYMMETRIC_DEFAULT"
],
"key_usage": "ENCRYPT_DECRYPT",
"key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_type_path": "defaultKeys",
"key_rotated": false,
"description": "Default master key that protects my Secrets Manager data when no other key is defined",
"key_state": "Enabled",
"customer_master_key_spec": "SYMMETRIC_DEFAULT",
"enabled": true,
"arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_manager": "AWS"
},
"metadata": {
"manual": {}
},
"reference": {
"resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
},
"tags": {
"a": "b"
},
"collection_info": {
"collectors": [],
"service_accounts": [],
"secrets": []
},
"ip_addresses": [],
"region_code": "ap-northeast-1",
"domain_id": "domain-58010aa2e451",
"created_at": "2022-06-22T06:38:48.989Z",
"updated_at": "2022-06-22T06:38:48.989Z",
"launched_at": "2020-08-03T15:00:54.000Z"
}delete #
Deletes a specific CloudService. You must specify the cloud_service_id of the CloudService to delete.
POST /inventory/v1/cloud-service/delete
cloud_service_id (string)
Requireddomain_id (string)
Required
{
"cloud_service_id": "cloud-svc-fea2b0d32141"
}get #
Gets a specific CloudService. Prints detailed information about the CloudService, including its state, classification information, and attribute values.
POST /inventory/v1/cloud-service/get
cloud_service_id (string)
Requireddomain_id (string)
Requiredonly (string)
Repeated
{
"cloud_service_id": "cloud-svc-fea2b0d32141"
}cloud_service_id (string)
Requiredname (string)
Requiredstate (string)
Requiredaccount (string)
Requiredinstance_type (string)
Requiredinstance_size (float)
Requiredcloud_service_type (string)
Requiredcloud_service_group (string)
Requiredprovider (string)
Requireddata (Struct)
Requiredmetadata (Struct)
Requiredreference (CloudServiceReference)
Requiredtags (Struct)
Requiredtag_keys (Struct)
Requiredcollection_info (CollectionInfo)
RepeatedRequiredip_addresses (string)
RepeatedRequiredregion_code (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Requireddeleted_at (string)
Required
{
"cloud_service_id": "cloud-svc-c00f38a173e1",
"name": "cloud_service_test",
"state": "ACTIVE",
"account": "251340636361",
"cloud_service_type": "Key",
"cloud_service_group": "KMS",
"provider": "aws",
"data": {
"alias_arn": null,
"origin": "AWS_KMS",
"cloudwatch": {
"region_name": "ap-northeast-1",
"namespace": "AWS/KMS",
"dimensions": [
{
"Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"Name": "KeyId"
}
]
},
"aws_account_id": "251340636361",
"creation_date": "2020-07-09T09:39:03.097000+0000",
"encryption_algorithms": [
"SYMMETRIC_DEFAULT"
],
"key_usage": "ENCRYPT_DECRYPT",
"key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_type_path": "defaultKeys",
"key_rotated": false,
"description": "Default master key that protects my Secrets Manager data when no other key is defined",
"key_state": "Enabled",
"customer_master_key_spec": "SYMMETRIC_DEFAULT",
"enabled": true,
"arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_manager": "AWS"
},
"metadata": {
"manual": {}
},
"reference": {
"resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
},
"tags": {
"a": "b"
},
"collection_info": {
"collectors": [],
"service_accounts": [],
"secrets": []
},
"ip_addresses": [],
"region_code": "ap-northeast-1",
"domain_id": "domain-58010aa2e451",
"created_at": "2022-06-22T06:38:48.989Z",
"updated_at": "2022-06-22T06:38:48.989Z",
"launched_at": "2020-08-03T15:00:54.000Z"
}list #
Gets a list of all CloudServices. You can use a query to get a filtered list of CloudServices.
POST /inventory/v1/cloud-service/list
domain_id (string)
Requiredquery (Query)
cloud_service_id (string)
name (string)
state (string)
account (string)
instance_type (string)
cloud_service_type (string)
cloud_service_group (string)
provider (string)
region_code (string)
ip_address (string)
project_id (string)
project_group_id (string)
{
"query": {
"filter": [
{
"key": "cloud_service_type",
"value": "Key",
"operator": "eq"
}
]
}
}results (CloudServiceInfo)
RepeatedRequiredtotal_count (int32)
Required
{
"results": [{
"cloud_service_id": "cloud-svc-c00f38a173e1",
"name": "cloud_service_test2",
"state": "ACTIVE",
"account": "251340636361",
"cloud_service_type": "Key",
"cloud_service_group": "KMS",
"provider": "aws",
"data": {
"alias_arn": null,
"origin": "AWS_KMS",
"cloudwatch": {
"region_name": "ap-northeast-1",
"namespace": "AWS/KMS",
"dimensions": [
{
"Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"Name": "KeyId"
}
]
},
"aws_account_id": "251340636361",
"creation_date": "2020-07-09T09:39:03.097000+0000",
"encryption_algorithms": [
"SYMMETRIC_DEFAULT"
],
"key_usage": "ENCRYPT_DECRYPT",
"key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_type_path": "defaultKeys",
"key_rotated": false,
"description": "Default master key that protects my Secrets Manager data when no other key is defined",
"key_state": "Enabled",
"customer_master_key_spec": "SYMMETRIC_DEFAULT",
"enabled": true,
"arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"key_manager": "AWS"
},
"metadata": {
"manual": {}
},
"reference": {
"resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
"external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
},
"tags": {
"description": "spaceone"
},
"collection_info": {
"collectors": [],
"service_accounts": [],
"secrets": []
},
"ip_addresses": [
"1.1.1.1",
"2.2.2.2"
],
"region_code": "ap-northeast-1",
"domain_id": "domain-58010aa2e451",
"created_at": "2022-06-22T06:38:48.989Z",
"updated_at": "2022-06-22T06:38:48.989Z",
"launched_at": "2020-08-03T15:00:54.000Z"
}],
"total_count": 1
}analyze #
POST /inventory/v1/cloud-service/analyze
stat #
POST /inventory/v1/cloud-service/stat
Message #
CloudServiceAnalyzeQuery #
query (AnalyzeQuery)
Requireddomain_id (string)
Required
CloudServiceInfo #
cloud_service_id (string)
Requiredname (string)
Requiredstate (string)
Requiredaccount (string)
Requiredinstance_type (string)
Requiredinstance_size (float)
Requiredcloud_service_type (string)
Requiredcloud_service_group (string)
Requiredprovider (string)
Requireddata (Struct)
Requiredmetadata (Struct)
Requiredreference (CloudServiceReference)
Requiredtags (Struct)
Requiredtag_keys (Struct)
Requiredcollection_info (CollectionInfo)
RepeatedRequiredip_addresses (string)
RepeatedRequiredregion_code (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Requiredupdated_at (string)
Requireddeleted_at (string)
Required
CloudServiceQuery #
domain_id (string)
Requiredquery (Query)
cloud_service_id (string)
name (string)
state (string)
account (string)
instance_type (string)
cloud_service_type (string)
cloud_service_group (string)
provider (string)
region_code (string)
ip_address (string)
project_id (string)
project_group_id (string)
CloudServiceReference #
resource_id (string)
Requiredexternal_link (string)
Required
CloudServiceRequest #
cloud_service_id (string)
Requireddomain_id (string)
Required
CloudServiceStatQuery #
query (StatisticsQuery)
Requireddomain_id (string)
Required
CloudServicesInfo #
results (CloudServiceInfo)
RepeatedRequiredtotal_count (int32)
Required
CollectionInfo #
provider (string)
Requiredservice_account_id (string)
Requiredsecret_id (string)
Requiredcollector_id (string)
Requiredlast_collected_at (string)
Required
CreateServiceRequest #
cloud_service_type (string)
Requiredprovider (string)
Requiredcloud_service_group (string)
Requireddata (Struct)
Requireddomain_id (string)
Requiredname (string)
account (string)
instance_type (string)
instance_size (float)
ip_addresses (string)
Repeatedmetadata (Struct)
reference (CloudServiceReference)
tags (Struct)
region_code (string)
project_id (string)
GetCloudServiceRequest #
cloud_service_id (string)
Requireddomain_id (string)
Requiredonly (string)
Repeated
PinCloudServiceDataRequest #
cloud_service_id (string)
Requiredkeys (string)
RepeatedRequireddomain_id (string)
Required
UpdateCloudServiceRequest #
cloud_service_id (string)
Requireddomain_id (string)
Requiredname (string)
account (string)
instance_type (string)
instance_size (float)
ip_addresses (string)
Repeateddata (Struct)
metadata (Struct)
reference (CloudServiceReference)
tags (Struct)
region_code (string)
project_id (string)
release_project (bool)
release_region (bool)